"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Bootstrap = exports.BootstrapStarter = exports.isTypeScriptEnvironment = void 0;
const path_1 = require("path");
function isTypeScriptEnvironment() {
    const TS_MODE_PROCESS_FLAG = process.env.MIDWAY_TS_MODE;
    if ('false' === TS_MODE_PROCESS_FLAG) {
        return false;
    }
    // eslint-disable-next-line node/no-deprecated-api
    return TS_MODE_PROCESS_FLAG === 'true' || !!require.extensions['.ts'];
}
exports.isTypeScriptEnvironment = isTypeScriptEnvironment;
class BootstrapStarter {
    constructor() {
        this.bootstrapItems = [];
    }
    configure(options) {
        this.globalOptions = options;
        return this;
    }
    load(unit) {
        this.bootstrapItems.push(unit);
        return this;
    }
    async init() {
        this.appDir = this.globalOptions.baseDir;
        await Promise.all(this.getActions('initialize', {
            ...this.globalOptions,
            baseDir: this.getBaseDir(),
            appDir: this.appDir,
        }));
    }
    async run() {
        await Promise.all(this.getActions('run', {}));
    }
    async stop() {
        await Promise.all(this.getActions('stop', {}));
    }
    getActions(action, args) {
        return this.bootstrapItems.map(item => {
            return item[action](args);
        });
    }
    getBaseDir() {
        if (isTypeScriptEnvironment()) {
            return path_1.join(this.appDir, 'src');
        }
        else {
            return path_1.join(this.appDir, 'dist');
        }
    }
}
exports.BootstrapStarter = BootstrapStarter;
class Bootstrap {
    /**
     * set global configuration for midway
     * @param configuration
     */
    static configure(configuration) {
        this.getStarter().configure(configuration);
        return this;
    }
    /**
     * load midway framework unit
     * @param unit
     */
    static load(unit) {
        this.getStarter().load(unit);
        return this;
    }
    static getStarter() {
        if (!this.starter) {
            this.starter = new BootstrapStarter();
        }
        return this.starter;
    }
    static async run() {
        await this.getStarter().init();
        return this.getStarter().run().catch(console.error);
    }
    static async stop() {
        return this.getStarter().stop().catch(console.error);
    }
}
exports.Bootstrap = Bootstrap;
//# sourceMappingURL=bootstrap.js.map